[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Cybex
Autonomously generate high-quality unit tests for entire repositories, just plug in and play the repo link and enjoy high quality tests to elevate your project


## Installation



# Architecture

# License
MIT



